Documentation
¶
Overview ¶
+k8s:openapi-gen=true +k8s:deepcopy-gen=package,register +groupName=proxy.open-cluster-management.io
Package v1alpha1 contains API Schema definitions for the proxy v1alpha1 API group +kubebuilder:object:generate=true +groupName=proxy.open-cluster-management.io
Index ¶
- Constants
- Variables
- func Resource(resource string) schema.GroupResource
- type ClusterGatewayConfiguration
- type ClusterGatewayConfigurationList
- type ClusterGatewayConfigurationSpec
- type ClusterGatewayConfigurationStatus
- type ClusterGatewaySecretManagement
- type ClusterGatewayTrafficEgress
- type ClusterGatewayTrafficEgressClusterProxy
- type ClusterGatewayTrafficEgressClusterProxyCredential
- type EgressType
- type SecretManagementManagedServiceAccount
- type SecretManagementType
Constants ¶
const ( EgressTypeDirect = "Direct" EgressTypeClusterProxy = "ClusterProxy" )
const ( SecretManagementTypeManual = "Manual" SecretManagementTypeManagedServiceAccount = "ManagedServiceAccount" )
const (
ConditionTypeClusterGatewayDeployed = "ClusterGatewayDeployed"
)
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "proxy.open-cluster-management.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme SchemeGroupVersion = GroupVersion )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Types ¶
type ClusterGatewayConfiguration ¶
type ClusterGatewayConfiguration struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ClusterGatewayConfigurationSpec `json:"spec,omitempty"`
Status ClusterGatewayConfigurationStatus `json:"status,omitempty"`
}
+genclient +genclient:nonNamespaced +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*ClusterGatewayConfiguration) DeepCopy ¶
func (in *ClusterGatewayConfiguration) DeepCopy() *ClusterGatewayConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewayConfiguration.
func (*ClusterGatewayConfiguration) DeepCopyInto ¶
func (in *ClusterGatewayConfiguration) DeepCopyInto(out *ClusterGatewayConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterGatewayConfiguration) DeepCopyObject ¶
func (in *ClusterGatewayConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterGatewayConfigurationList ¶
type ClusterGatewayConfigurationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ClusterGatewayConfiguration `json:"items"`
}
+k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*ClusterGatewayConfigurationList) DeepCopy ¶
func (in *ClusterGatewayConfigurationList) DeepCopy() *ClusterGatewayConfigurationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewayConfigurationList.
func (*ClusterGatewayConfigurationList) DeepCopyInto ¶
func (in *ClusterGatewayConfigurationList) DeepCopyInto(out *ClusterGatewayConfigurationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterGatewayConfigurationList) DeepCopyObject ¶
func (in *ClusterGatewayConfigurationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterGatewayConfigurationSpec ¶
type ClusterGatewayConfigurationSpec struct {
// +required
Image string `json:"image"`
// +required
SecretNamespace string `json:"secretNamespace"`
// +required
InstallNamespace string `json:"installNamespace"`
// +required
SecretManagement ClusterGatewaySecretManagement `json:"secretManagement"`
// +required
Egress ClusterGatewayTrafficEgress `json:"egress"`
}
func (*ClusterGatewayConfigurationSpec) DeepCopy ¶
func (in *ClusterGatewayConfigurationSpec) DeepCopy() *ClusterGatewayConfigurationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewayConfigurationSpec.
func (*ClusterGatewayConfigurationSpec) DeepCopyInto ¶
func (in *ClusterGatewayConfigurationSpec) DeepCopyInto(out *ClusterGatewayConfigurationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterGatewayConfigurationStatus ¶
type ClusterGatewayConfigurationStatus struct {
// +optional
LastObservedGeneration int64 `json:"lastObservedGeneration,omitempty"`
// +optional
Conditions []metav1.Condition `json:"conditions,omitempty"`
}
func (*ClusterGatewayConfigurationStatus) DeepCopy ¶
func (in *ClusterGatewayConfigurationStatus) DeepCopy() *ClusterGatewayConfigurationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewayConfigurationStatus.
func (*ClusterGatewayConfigurationStatus) DeepCopyInto ¶
func (in *ClusterGatewayConfigurationStatus) DeepCopyInto(out *ClusterGatewayConfigurationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterGatewaySecretManagement ¶
type ClusterGatewaySecretManagement struct {
// +optional
// +kubebuilder:default=ManagedServiceAccount
Type SecretManagementType `json:"type"`
// +optional
ManagedServiceAccount *SecretManagementManagedServiceAccount `json:"managedServiceAccount,omitempty"`
}
func (*ClusterGatewaySecretManagement) DeepCopy ¶
func (in *ClusterGatewaySecretManagement) DeepCopy() *ClusterGatewaySecretManagement
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewaySecretManagement.
func (*ClusterGatewaySecretManagement) DeepCopyInto ¶
func (in *ClusterGatewaySecretManagement) DeepCopyInto(out *ClusterGatewaySecretManagement)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterGatewayTrafficEgress ¶
type ClusterGatewayTrafficEgress struct {
Type EgressType `json:"type"`
ClusterProxy *ClusterGatewayTrafficEgressClusterProxy `json:"clusterProxy,omitempty"`
}
func (*ClusterGatewayTrafficEgress) DeepCopy ¶
func (in *ClusterGatewayTrafficEgress) DeepCopy() *ClusterGatewayTrafficEgress
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewayTrafficEgress.
func (*ClusterGatewayTrafficEgress) DeepCopyInto ¶
func (in *ClusterGatewayTrafficEgress) DeepCopyInto(out *ClusterGatewayTrafficEgress)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterGatewayTrafficEgressClusterProxy ¶
type ClusterGatewayTrafficEgressClusterProxy struct {
ProxyServerHost string `json:"proxyServerHost"`
ProxyServerPort int32 `json:"proxyServerPort"`
Credentials ClusterGatewayTrafficEgressClusterProxyCredential `json:"credentials"`
}
func (*ClusterGatewayTrafficEgressClusterProxy) DeepCopy ¶
func (in *ClusterGatewayTrafficEgressClusterProxy) DeepCopy() *ClusterGatewayTrafficEgressClusterProxy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewayTrafficEgressClusterProxy.
func (*ClusterGatewayTrafficEgressClusterProxy) DeepCopyInto ¶
func (in *ClusterGatewayTrafficEgressClusterProxy) DeepCopyInto(out *ClusterGatewayTrafficEgressClusterProxy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterGatewayTrafficEgressClusterProxyCredential ¶
type ClusterGatewayTrafficEgressClusterProxyCredential struct {
Namespace string `json:"namespace"`
ProxyClientSecretName string `json:"proxyClientSecretName"`
ProxyClientCASecretName string `json:"proxyClientCASecretName"`
}
func (*ClusterGatewayTrafficEgressClusterProxyCredential) DeepCopy ¶
func (in *ClusterGatewayTrafficEgressClusterProxyCredential) DeepCopy() *ClusterGatewayTrafficEgressClusterProxyCredential
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGatewayTrafficEgressClusterProxyCredential.
func (*ClusterGatewayTrafficEgressClusterProxyCredential) DeepCopyInto ¶
func (in *ClusterGatewayTrafficEgressClusterProxyCredential) DeepCopyInto(out *ClusterGatewayTrafficEgressClusterProxyCredential)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EgressType ¶
type EgressType string
type SecretManagementManagedServiceAccount ¶
type SecretManagementManagedServiceAccount struct {
// +optional
// +kubebuilder:default=cluster-gateway
Name string `json:"name"`
}
func (*SecretManagementManagedServiceAccount) DeepCopy ¶
func (in *SecretManagementManagedServiceAccount) DeepCopy() *SecretManagementManagedServiceAccount
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretManagementManagedServiceAccount.
func (*SecretManagementManagedServiceAccount) DeepCopyInto ¶
func (in *SecretManagementManagedServiceAccount) DeepCopyInto(out *SecretManagementManagedServiceAccount)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SecretManagementType ¶
type SecretManagementType string
+kubebuilder:validation:Enum=Manual;ManagedServiceAccount